Battery
=======

.. autoclass:: physics.models.battery.BasicBattery
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: physics.models.battery.BaseBattery
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: physics.models.battery.BatteryModel
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: physics.models.battery.BatteryModelConfig
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: physics.models.battery.KalmanFilterConfig
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: physics.models.battery.EquivalentCircuitBatteryModel
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: physics.models.battery.FilteredBatteryModel
   :members:
   :undoc-members:
   :show-inheritance:
